/********************************************************
Workspace: IAR+SPL
Chip type: STM8S103K3
Project  : thermofan controller
Version  : 4_b - for small fan from soldering station
Date     : Jan 2021
*********************************************************/
#include "stm8s.h"
#include "iostm003.c"
#include "stm8s_flash.c"
#include "stm8s_itc.c"
#include "stm8s_iwdg.c"

#include <stdbool.h>
#include <math.h>

#include "bitset.c"
#include "defines.c"
#include "periph_init.c"
#include "kwork.c"
#include "eeprom_routines.c"
#include "apow_work.c"
#include "pwm_routines.c"
#include "ledwork.c"
#include "ss_routines.c"
#include "misc.c"

#include "interrupts.c"

void devcon(void);

void main()
{
 cfg.gpio();
 cfg.clk();
 cfg.t1();
 cfg.t2();
 cfg.t4();

 cfg.ee();

 cfg.iwdg();

 asm("rim");

 endless
 {
  //1   
  if(TIM4->SR1)
  {
   TIM4->SR1 = 0;

   for(int i=0; i<T_size; i++) if(Tim[i]) Tim[i]--;

   if(TIM_50Hz == 0)
   {
    TIM_50Hz  = 10;
    OUT_50Hz ^= 1;
   }

   scan_keys();
  }

  devcon();
  display_data();

  if(iwdg_t2)
  {
   iwdg_t2 = false;

   IWDG_ReloadCounter();
//   if(check_pwm_reg()==true) IWDG_ReloadCounter();
  }
 }
}

void devcon()
{
 static bool itr;
 static enum {start,work,sdn} dev_st = start, dev_st_tmp;
 static bool btn_trg;
 static u16 off_cntdn = OFF_TIME;

 static u8 heat;
 static u8 airflow;

 if(btn[0]==rls && btn[1]==rls) btn_trg=0;
 else off_cntdn = OFF_TIME;

 //  
 if(!TIM_OFF)
 {
  if(off_cntdn)
  {
   off_cntdn--;
   TIM_OFF = T_SEC*60;
  }
  else dev_st = sdn;
 }

 if(dev_st != dev_st_tmp)
 {
  dev_st_tmp = dev_st;

  itr = 0;
 }

 switch (dev_st)
 {
  case start:
  {
   static u8 cnt;

   if(!itr)
   {
    itr = 1;
    LED_0 = 1;
    TIM_DLY = T_SEC*2/5;
    cnt = 0;

    get_pwm_constraints();
    airflow = 9;
    heat    = 0;

    dbuf = 17;
    dpp  = 0;
   }

   if(!TIM_DLY)
   {
    if(cnt < 2)
    {
     cnt++;
     dbuf++;

     TIM_DLY = T_SEC*2/5;
    }
    else
    {
     if(read_ee(eep.onoff)== 0) dev_st = sdn;
     else                       dev_st = work;
    }
   }
  }
  break;

  case work:
  {
   static enum {reg_heat, reg_airflow} reg_mode;

   if(!itr)
   {
    itr = 1;

    heat    = read_ee(eep.heatpow);
    airflow = read_ee(eep.airflow);

    reg_mode  = reg_heat;
   }

   //   
   {
    if(reg_mode == reg_heat)
    {
     dbuf = heat;
     dpp = 1;
    }
    else
    {
     dbuf = airflow;
     dpp = 0;
    }
   }

   led_blink(heat, TIM_BLINK);

   /*
       

       -   
        ++/-- 
       -    
         
   */
   {
    //            
    if(!btn_trg)
    {
     static Btn_enum btmp[2];
     static bool cprs_trg;

     //       
     if(cprs_trg==true && btn[0]==rls && btn[1]==rls)
     {
      cprs_trg = false;

      if(reg_mode == reg_heat) reg_mode = reg_airflow;
      else                     reg_mode = reg_heat;
     }
     else
     {
      if(btn[0]==prs && btn[1]==prs)
      {
       cprs_trg = true;
       for(u8 i=0; i<2; i++)btmp[i] = rls;
      }
      else
      {
       u8 someval;

       if(reg_mode == reg_heat) someval = heat;
       else                     someval = airflow;

       if(cprs_trg==false)
       for(u8 i = 0; i < 2; i++)
       {
        //  
        if(btmp[i] != btn[i])
        {
         // 
         if(btn[i] == rls)
         {
          //   
          if(btmp[i]==prs)
          {
           //   
           if(i==0)
           {
            if(someval) someval--;
           }
           //   
           else
           {
            if(someval < 9) someval++;
           }
          }
         }
         else if(btn[i]==hold) cprs_trg = false;

         btmp[i] = btn[i];
        }
       }

       //_//     
       if(!TIM_BTN)
       {
        TIM_BTN = T_SEC/3;

        if(btn[0]==hold && btn[1]==rls)
        {
         if(someval) someval--;
        }
        else if(btn[1]==hold && btn[0]==rls)
        {
         if(someval < 9) someval++;
        }
       }

       // 
       if(reg_mode == reg_heat)
       {
        //      
        if(someval > airflow + OVERSTEP)heat = airflow + OVERSTEP;
        else                            heat = someval;
       }
       else
       {
        //       
        if(someval + OVERSTEP < heat) airflow = heat - OVERSTEP;
        else                          airflow = someval;
       }

       //   -   
       if(btn[0]==hold && btn[1]==hold)
       {
        btn_trg  = 1;
        cprs_trg = false;
        btmp[0]  = rls;
        btmp[1]  = rls;

        if(airflow != read_ee(eep.airflow)) write_ee(airflow, eep.airflow);
        if(heat    != read_ee(eep.heatpow)) write_ee(heat,    eep.heatpow);

        dev_st = sdn;
       }
      }
     }
    }
   }
  }
  break;

  case sdn:
  {
   if(!itr)
   {
    itr = 1;

    // 
    TIM_DLY = T_SEC * 30;

    LED_0 = 0;

    // 
    heat = 0;
    //   
    airflow = 9;

    //          eeprom
    if(read_ee(eep.onoff)==1) write_ee(0, eep.onoff);
    //      
    else TIM_DLY = 0;
   }

   //   
   if(!TIM_DLY)
   {
    airflow = 0;

    dbuf = ' ';
    dpp = 1;
   }
   //  
   else
   {
    if(!TIM_BLINK)
    {
     u8 tmp = TIM_DLY / T_SEC;

     if(tmp > 9)
     {
      TIM_BLINK = T_SEC/5;

      if(dbuf < 15 && dbuf > 9) dbuf++;
      else dbuf = 10;
     }
     else
     {
      dbuf = tmp;
      dpp  = 0;
     }
    }
   }

   //       
   if(!btn_trg)
   if(btn[0]==hold && btn[1]==hold)
   {
    btn_trg = 1;
    write_ee(1, eep.onoff);
    dev_st = start;
   }
  }
  break;
 }

 //       
 {
  static u8 heat_tmp = 0xff;
  static u8 flow_tmp;
  static u8 bust_tmp;
  u8 aft;

  if(airflow > bust_tmp) TIM_TURBO = T_SEC/3;

  bust_tmp = airflow;

  if(TIM_TURBO) aft = 9;
  else          aft = airflow;

  if(flow_tmp != aft)
  {
   flow_tmp = aft;
   set_vent_pow (aft);
  }

  if(heat_tmp != heat)
  {
   heat_tmp = heat;
   Bta_pow  = heat;
  }
 }
}